@@ -392,7 +392,9 @@ as_cache_remove_old_data_from_dir (AsCache *cache, const gchar *cache_dir)
 		fname_full = g_build_filename (cache_dir, g_file_info_get_name (finfo), NULL);
 
 		/* jump one directory deeper */
-		if (g_file_info_get_file_type (finfo) == G_FILE_TYPE_DIRECTORY) {
+		if (g_file_info_get_file_type (finfo) == G_FILE_TYPE_DIRECTORY ||
+		    (g_file_info_get_file_type (finfo) == G_FILE_TYPE_SYMBOLIC_LINK &&
+		     g_file_test (fname_full, G_FILE_TEST_IS_DIR))) {
 			g_autoptr(GFileEnumerator) sd_direnum = NULL;
 			g_autoptr(GFile) sd_cdir = NULL;
 
@@ -1586,16 +1588,17 @@ as_cache_get_component_count (AsCache *cache)
 	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_reader_locker_new (&priv->rw_lock);
 
 	for (guint i = 0; i < priv->sections->len; i++) {
-		g_autoptr(XbNode) n = NULL;
+		XbNode *n = NULL;
 		g_autoptr(XbNode) node = NULL;
 		AsCacheSection *csec = (AsCacheSection *) g_ptr_array_index (priv->sections, i);
 
 		node = xb_silo_get_root (csec->silo);
 		n = xb_node_get_child (node);
 		while (n != NULL) {
+			XbNode *current_n = n;
 			cpt_node_count++;
-			g_object_unref (n);
-			n = xb_node_get_next (n);
+			n = xb_node_get_next (current_n);
+			g_object_unref (current_n);
 		}
 	}
 
