@@ -31,8 +31,11 @@ G_BEGIN_DECLS
 gboolean as_checksum_load_from_xml (AsChecksum *cs, AsContext *ctx, xmlNode *node, GError **error);
 void	 as_checksum_to_xml_node (AsChecksum *cs, AsContext *ctx, xmlNode *root);
 
-gboolean as_checksum_load_from_yaml (AsChecksum *cs, AsContext *ctx, GNode *node, GError **error);
-void	 as_checksum_emit_yaml (AsChecksum *cs, AsContext *ctx, yaml_emitter_t *emitter);
+gboolean as_checksum_load_from_yaml (AsChecksum		 *cs,
+				     AsContext		 *ctx,
+				     struct fy_node_pair *fynp,
+				     GError		**error);
+void	 as_checksum_emit_yaml (AsChecksum *cs, AsContext *ctx, struct fy_emitter *emitter);
 
 #pragma GCC visibility pop
 G_END_DECLS
