@@ -31,8 +31,11 @@ G_BEGIN_DECLS
 gboolean as_issue_load_from_xml (AsIssue *issue, AsContext *ctx, xmlNode *node, GError **error);
 void	 as_issue_to_xml_node (AsIssue *issue, AsContext *ctx, xmlNode *root);
 
-gboolean as_issue_load_from_yaml (AsIssue *issue, AsContext *ctx, GNode *node, GError **error);
-void	 as_issue_emit_yaml (AsIssue *issue, AsContext *ctx, yaml_emitter_t *emitter);
+gboolean as_issue_load_from_yaml (AsIssue	 *issue,
+				  AsContext	 *ctx,
+				  struct fy_node *node,
+				  GError	**error);
+void	 as_issue_emit_yaml (AsIssue *issue, AsContext *ctx, struct fy_emitter *emitter);
 
 #pragma GCC visibility pop
 G_END_DECLS
