@@ -25,9 +25,8 @@
 #include "asc-utils-l10n.h"
 #include "asc-utils-screenshots.h"
 #include "asc-utils-fonts.h"
-#include "asc-image.h"
+#include "asc-image-private.h"
 #include "asc-canvas.h"
-#include "asc-canvas-private.h"
 
 #include "as-utils-private.h"
 #include "as-test-utils.h"
@@ -267,6 +266,7 @@ test_image_transform (void)
 {
 	g_autoptr(GHashTable) supported_fmts = NULL;
 	g_autofree gchar *sample_img_fname = NULL;
+	g_autofree gchar *sample_jxl_img_fname = NULL;
 	g_autoptr(AscImage) image = NULL;
 	g_autoptr(GError) error = NULL;
 	gboolean ret;
@@ -281,9 +281,14 @@ test_image_transform (void)
 	g_assert_true (g_hash_table_contains (supported_fmts, "jpeg"));
 
 	sample_img_fname = g_build_filename (datadir, "appstream-logo.png", NULL);
+	sample_jxl_img_fname = g_build_filename (datadir, "image.jxl", NULL);
 
 	/* load image from file */
-	image = asc_image_new_from_file (sample_img_fname, 0, ASC_IMAGE_LOAD_FLAG_NONE, &error);
+	image = asc_image_new_from_file (sample_img_fname,
+					 -1,
+					 -1,
+					 ASC_IMAGE_LOAD_FLAG_NONE,
+					 &error);
 	g_assert_no_error (error);
 	g_assert_nonnull (image);
 
@@ -304,8 +309,7 @@ test_image_transform (void)
 	g_assert_no_error (error);
 	g_assert_true (ret);
 
-	g_object_unref (image);
-	image = NULL;
+	g_clear_object (&image);
 
 	/* test reading image from memory */
 	g_file_get_contents (sample_img_fname, &data, &data_len, &error);
@@ -313,9 +317,10 @@ test_image_transform (void)
 
 	image = asc_image_new_from_data (data,
 					 data_len,
-					 0,
-					 FALSE,
+					 -1,
+					 -1,
 					 ASC_IMAGE_LOAD_FLAG_NONE,
+					 ASC_IMAGE_FORMAT_UNKNOWN,
 					 &error);
 	g_assert_no_error (error);
 	g_assert_nonnull (image);
@@ -329,6 +334,26 @@ test_image_transform (void)
 				       &error);
 	g_assert_no_error (error);
 	g_assert_true (ret);
+	g_clear_object (&image);
+
+	/* test loading a JPEG-XL image */
+	image = asc_image_new_from_file (sample_jxl_img_fname,
+					 -1,
+					 -1,
+					 ASC_IMAGE_LOAD_FLAG_NONE,
+					 &error);
+	if (g_hash_table_contains (supported_fmts, "jxl")) {
+		g_assert_no_error (error);
+		g_assert_nonnull (image);
+
+		g_assert_cmpint (asc_image_get_width (image), ==, 64);
+		g_assert_cmpint (asc_image_get_height (image), ==, 64);
+	} else {
+		g_assert_error (error, ASC_IMAGE_ERROR, ASC_IMAGE_ERROR_UNSUPPORTED);
+		g_assert_null (image);
+		g_clear_error (&error);
+	}
+	g_clear_object (&image);
 }
 
 /**
@@ -343,6 +368,9 @@ test_canvas (void)
 	g_autofree gchar *font_fname = NULL;
 	g_autofree gchar *data = NULL;
 	gsize data_len;
+	gint cv_size;
+	gint text_border_width, shape_border_width;
+	AscCanvasShape bg_shape;
 	g_autoptr(AscCanvas) cv = NULL;
 	g_autoptr(AscFont) font = NULL;
 	g_autoptr(GInputStream) stream = NULL;
@@ -386,20 +414,30 @@ test_canvas (void)
 	g_assert_no_error (error);
 	g_object_unref (cv);
 
-	cv = asc_canvas_new (64, 64);
+	cv_size = 128;
+	bg_shape = ASC_CANVAS_SHAPE_CVL_TRIANGLE;
+	shape_border_width = (gint) (cv_size * 0.032);
+	text_border_width = asc_calculate_text_border_width_for_icon_shape (bg_shape,
+									    cv_size,
+									    shape_border_width);
+
+	cv = asc_canvas_new (cv_size, cv_size);
 	asc_canvas_draw_shape (cv,
-			       ASC_CANVAS_SHAPE_HEXAGON,
-			       2,    /* border width */
-			       0.85, /* red */
-			       0.85, /* green */
-			       0.85, /* blue */
+			       bg_shape,
+			       shape_border_width,
+			       0.84, /* red */
+			       0.84, /* green */
+			       0.84, /* blue */
 			       &error);
 	g_assert_no_error (error);
 
 	asc_canvas_draw_text_line (cv,
 				   font,
 				   "Aa",
-				   10, /* border width */
+				   text_border_width,
+				   bg_shape == ASC_CANVAS_SHAPE_CVL_TRIANGLE
+				       ? (gint) ((cv_size / 2.0 - shape_border_width) * 0.15)
+				       : 0,
 				   &error);
 	g_assert_no_error (error);
 	asc_canvas_save_png (cv, "/tmp/asc-fontrender_test2.png", &error);
@@ -754,11 +792,11 @@ test_compose_directory_unit (void)
 	g_assert_true (ret);
 
 	contents = asc_unit_get_contents (ASC_UNIT (dirunit));
-	g_assert_cmpint (contents->len, ==, 16);
+	g_assert_cmpint (contents->len, ==, 17);
 	as_sort_strings (contents);
 
 	g_assert_cmpstr (g_ptr_array_index (contents, 0), ==, "/Raleway-Regular.ttf");
-	g_assert_cmpstr (g_ptr_array_index (contents, 5), ==, "/table.svgz");
+	g_assert_cmpstr (g_ptr_array_index (contents, 5), ==, "/sample-video.mkv");
 
 	/* read existent data */
 	g_assert_true (asc_unit_file_exists (ASC_UNIT (dirunit), "/usr/dummy"));
