@@ -24,6 +24,7 @@
 #include "appstream.h"
 #include "as-screenshot-private.h"
 #include "as-metadata.h"
+#include "as-yaml.h"
 #include "as-test-utils.h"
 
 static gchar *datadir = NULL;
@@ -291,11 +292,11 @@ test_yamlwrite_misc (void)
 	    "  description:\n"
 	    "    C: >-\n"
 	    "      <p>Awesome initial release.</p>\n"
-	    "\n"
+	    "      \n"
 	    "      <p>Second paragraph.</p>\n"
 	    "    de-DE: >-\n"
 	    "      <p>Großartige erste Veröffentlichung.</p>\n"
-	    "\n"
+	    "      \n"
 	    "      <p>Zweite zeile.</p>\n"
 	    "  url:\n"
 	    "    details: https://example.org/releases/1.0.html\n"
@@ -1055,7 +1056,7 @@ static const gchar *yamldata_relations_field = "Type: generic\n"
 					       "- id: org.example.old_test\n"
 					       "Requires:\n"
 					       "- kernel: Linux\n"
-					       "  version: '>= 4.15'\n"
+					       "  version: \">= 4.15\"\n"
 					       "- id: org.example.TestDependency\n"
 					       "  version: == 1.2\n"
 					       "- display_length: 4200\n"
@@ -1416,7 +1417,11 @@ static const gchar *yamldata_screenshots = "Type: generic\n"
 					   "- environment: plasma:mobile\n"
 					   "  caption:\n"
 					   "    C: The app, on mobile!\n"
+#if AS_FYAML_CHECK_VERSION(0, 9)
 					   "  thumbnails: []\n"
+#else
+					   "  thumbnails:\n"
+#endif
 					   "  source-image:\n"
 					   "    url: https://example.org/alpha_mobile.png\n"
 					   "    width: 640\n"
@@ -1650,11 +1655,11 @@ static const gchar *yamldata_releases_field =
     "  description:\n"
     "    C: >-\n"
     "      <p>Awesome initial release.</p>\n"
-    "\n"
+    "      \n"
     "      <p>Second paragraph.</p>\n"
     "    de-DE: >-\n"
     "      <p>Großartige erste Veröffentlichung.</p>\n"
-    "\n"
+    "      \n"
     "      <p>Zweite zeile.</p>\n"
     "  url:\n"
     "    details: https://example.org/releases/1.0.html\n";
@@ -1875,10 +1880,10 @@ test_yaml_rw_branding (void)
 					    "  colors:\n"
 					    "  - type: primary\n"
 					    "    scheme-preference: light\n"
-					    "    value: '#ff00ff'\n"
+					    "    value: \"#ff00ff\"\n"
 					    "  - type: primary\n"
 					    "    scheme-preference: dark\n"
-					    "    value: '#993d3d'\n";
+					    "    value: \"#993d3d\"\n";
 	g_autoptr(AsComponent) cpt = NULL;
 	g_autofree gchar *res = NULL;
 	AsBranding *branding;
